yakumo.session

Package yakumo :: Module session |
[hide private]
[frames] | no frames]

# Module session

source code

utility function(s) for session

Classes | [hide private]
| SessionProxy
| Session

Functions | [hide private]
get_session(**kwargs) Session class dispatcher | source code
reauth(func) | source code
exception_translator(func) | source code
safe_json_load(func) | source code

Variables | [hide private]
| CHUNK_SIZE = `4096`
| __package__ = ``'``yakumo``'``

Function Details | [hide private]

### get_session(**kwargs) | source code
Session class dispatcher :return: Session class